==> monodevelop_2.8.6.3%2Bdfsg.orig.tar.gz: monodevelop-2.8.6.3/src/addins/MonoDevelop.MacDev/AppleSdkSettingsPanel.cs <==
// 
// AppleSdkSettingsPanel.cs
//  
// Author:
//       Michael Hutchinson <mhutch@xamarin.com>
// 
// Copyright (c) 2011 Xamarin Inc. (http://xamarin.com)
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using MonoDevelop.Core;
using MonoDevelop.Ide.Gui.OptionPanels;
using MonoMac.Foundation;

namespace MonoDevelop.MacDev
{
	class AppleSdkSettingsPanel : SdkLocationPanel
	{
		public override string Label {
			get { return GettextCatalog.GetString ("Apple SDK"); }
		}
		
		public override FilePath DefaultSdkLocation {
			get { return AppleSdkSettings.DefaultRoot; }
		}
		
		public override bool ValidateSdkLocation (FilePath location)
		{
			return AppleSdkSettings.ValidateSdkLocation (location);
		}
		
		public override FilePath LoadSdkLocationSetting ()
		{
			return AppleSdkSettings.GetConfiguredSdkLocation ();
		}
		
		public override void SaveSdkLocationSetting (FilePath location)
		{
			AppleSdkSettings.SetConfiguredSdkLocation (location);
		}
	}
}

==> monodevelop_3.0.2%2Bdfsg.orig.tar.gz: monodevelop-3.0.2/src/addins/MonoDevelop.MacDev/AppleSdkSettingsPanel.cs <==
// 
// AppleSdkSettingsPanel.cs
//  
// Author:
//       Michael Hutchinson <mhutch@xamarin.com>
// 
// Copyright (c) 2011 Xamarin Inc. (http://xamarin.com)
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using MonoDevelop.Core;
using MonoDevelop.Ide.Gui.OptionPanels;
using MonoMac.Foundation;

namespace MonoDevelop.MacDev
{
	class AppleSdkSettingsPanel : SdkLocationPanel
	{
		public override string Label {
			get { return GettextCatalog.GetString ("Apple SDK"); }
		}
		
		public override FilePath DefaultSdkLocation {
			get { return AppleSdkSettings.DefaultRoot; }
		}
		
		public override bool ValidateSdkLocation (FilePath location)
		{
			FilePath xcode, vplist, devroot;
			return AppleSdkSettings.ValidateSdkLocation (location, out xcode, out vplist, out devroot);
		}
		
		public override FilePath LoadSdkLocationSetting ()
		{
			return AppleSdkSettings.GetConfiguredSdkLocation ();
		}
		
		public override void SaveSdkLocationSetting (FilePath location)
		{
			AppleSdkSettings.SetConfiguredSdkLocation (location);
		}
	}
}
